@@ -12,6 +12,7 @@ import string
 import random
 
 from kgdt.models.graph import GraphData
+from tqdm import tqdm
 
 from sckg.buildtrie import Buildtrim
 
@@ -29,6 +30,9 @@ class SoftwareKG:
     def get_node_num(self):
         return self.graph.get_node_num()
 
+    def get_relation_num(self):
+        return self.graph.get_relation_num()
+
     def get_node_ids(self):
         return self.graph.get_node_ids()
 
@@ -79,6 +83,17 @@ class SoftwareKG:
                 result.append(relation[2])
         return result
 
+    def find_out_is_a_relation_concept_by_id(self, id):
+        start_word = self.get_concept_by_id(id)
+        # print(start_word)
+        out_relations = self.get_out_relations(start_word)
+        result = []
+        for relation in out_relations:
+            if relation[1] == 'is a':
+                node = self.get_node_by_concept(relation[2])
+                result.append(node)
+        return result
+
     def find_in_is_a_relation_concept(self, start_word):
         in_relations = self.get_in_relations(start_word)
         result = []
@@ -95,6 +110,16 @@ class SoftwareKG:
                 result.append(relation[2])
         return result
 
+    def find_out_facet_of_relation_concept_by_id(self, id):
+        start_word = self.get_concept_by_id(id)
+        out_relations = self.get_out_relations(start_word)
+        result = []
+        for relation in out_relations:
+            if relation[1] == 'facet of':
+                node = self.get_node_by_concept(relation[2])
+                result.append(node)
+        return result
+
     def find_in_facet_of_relation_concept(self, start_word):
         in_relations = self.get_in_relations(start_word)
         result = []
@@ -255,5 +280,39 @@ class SoftwareKG:
                 continue
             if float(node['properties']['score']) < 0.96:
                 continue
-            count.append(self.get_concept_by_id(number))
+            if not self.find_out_is_a_relation_concept(self.get_concept_by_id(number)):
+                continue
+            count.append(node)
         return count
+
+    def get_random_lastest_node(self):
+        count = []
+        max_num = self.graph.get_node_num()
+        while len(count) < 5:
+            number = random.randint(max_num-2000, max_num)
+            # print(number)
+            node = self.graph.get_node_info_dict(number)
+            if not node:
+                continue
+            if not self.find_out_is_a_relation_concept(self.get_concept_by_id(number)):
+                continue
+            count.append(node)
+        return count
+
+    def get_hot_concepts(self):
+        result = []
+        for id in tqdm(self.graph.get_node_ids()):
+            node = self.graph.get_node_info_dict(id)
+            if not node:
+                continue
+            if not 'frequency' in node['properties']:
+                continue
+            f = node['properties']['sum_frequency']
+            frequency = {
+                "concept": node['properties']['concept_name'],
+                "frequency": f,
+                "id": id
+            }
+            result.append(frequency)
+        result = sorted(result, key=lambda e: e['frequency'], reverse=True)
+        return result[0:10]
