@@ -58,20 +58,20 @@ class TestSckg(unittest.TestCase):
         assert sckg.is_exist_concept("java") == True
 
     def test_get_node_by_concept(self):
-        graph_path = PathUtil.graph_data("KG", "test")
-        tree = PathUtil.trie("Trie", "V1.0.2")
+        graph_path = PathUtil.graph_data("KG", "V1.0.6")
+        tree = PathUtil.trie("Trie", "V1.0.7")
         sckg = SoftwareKG(graph_path, tree)
-        print(sckg.get_node_by_concept("I'm trying to"))
+        print(sckg.get_node_by_concept("java"))
 
     def test_get_in_relations(self):
-        graph_path = PathUtil.graph_data("KG", "test")
-        tree = PathUtil.trie("Trie", "V1.0.2")
+        graph_path = PathUtil.graph_data("KG", "V1.0.6")
+        tree = PathUtil.trie("Trie", "V1.0.7")
         sckg = SoftwareKG(graph_path, tree)
         print(sckg.get_in_relations("java"))
 
     def test_get_out_relations(self):
-        graph_path = PathUtil.graph_data("KG", "test")
-        tree = PathUtil.trie("Trie", "V1.0.2")
+        graph_path = PathUtil.graph_data("KG", "V1.0.6")
+        tree = PathUtil.trie("Trie", "V1.0.7")
         sckg = SoftwareKG(graph_path, tree)
         print(sckg.get_out_relations("java"))
 
@@ -145,7 +145,38 @@ class TestSckg(unittest.TestCase):
         print(sckg.get_common_upper_concept("java", 'python'))
 
     def test_get_random_node(self):
-        graph_path = PathUtil.graph_data("KG", "test")
-        tree = PathUtil.trie("Trie", "V1.0.2")
+        graph_path = PathUtil.graph_data("KG", "V1.0.6")
+        tree = PathUtil.trie("Trie", "V1.0.7")
         sckg = SoftwareKG(graph_path, tree)
         print(sckg.get_random_node())
+
+    def test_get_hot_concept(self):
+        graph_path = PathUtil.graph_data("KG", "V1.0.6")
+        tree = PathUtil.trie("Trie", "V1.0.7")
+        sckg = SoftwareKG(graph_path, tree)
+        print(sckg.get_hot_concepts())
+
+    def test_get_random_lasted_node(self):
+        graph_path = PathUtil.graph_data("KG", "V1.0.6")
+        tree = PathUtil.trie("Trie", "V1.0.7")
+        sckg = SoftwareKG(graph_path, tree)
+        print(sckg.get_random_lastest_node())
+
+    def test_find_out_is_a_relation_concept_by_id(self):
+        graph_path = PathUtil.graph_data("KG", "V1.0.6")
+        tree = PathUtil.trie("Trie", "V1.0.7")
+        sckg = SoftwareKG(graph_path, tree)
+        print(sckg.find_out_is_a_relation_concept_by_id(5817))
+
+    def test_get_node_num(self):
+        graph_path = PathUtil.graph_data("KG", "V1.0.6")
+        tree = PathUtil.trie("Trie", "V1.0.7")
+        sckg = SoftwareKG(graph_path, tree)
+        print(sckg.get_node_num())
+
+    def test_get_relation_num(self):
+        graph_path = PathUtil.graph_data("KG", "V1.0.6")
+        tree = PathUtil.trie("Trie", "V1.0.7")
+        sckg = SoftwareKG(graph_path, tree)
+        print(sckg.get_relation_num())
+
